function [R,H]=bl2gk(B,L,L0,ell)
// Transformation: Geodtischen ellipsoidischen Koordinaten
// in  Gau-Krger-Koordinaten (deutsche Konvention)
//
// [R, H] = bl2gk(B, L, L0 [,ell])
//
// in : B   - Breite [grad.decimale],
//      L   - Lnge [grad.decimale],
//      L0  - Nullmeridian [grad],
//      ell - Textstring: 'wgs84', 'grs80', oder 'bessel' (default)
// out: R   - Rechtswert [m],
//      H   - Hochwert [m]
//
// Geschlossene Formeln, Reihenentwicklung nur fr Meridianbogenlnge aus
// Fupunktbreite nach K. Schndelbach, Skript Landesvermessung 
//
// (matrixfhig)
//
// Copyright (c) area7/Christof Schulze  2008
//--------------------------------------------------------------

if nargin < 4, ell = 'bessel'; end;  // Bessel default
  
ell = convstr(stripblanks(ell), 'l');
if ell=='bessel',       		  // Bessel-Ellipsoid 
   a  = 6377397.155;        // groe Halbachse
   c  = 6398786.849;        // a*a/b
   es = 0.006719218798;     // (a*a-b*b)/(b*b)
   n  = 0.001674184801;     // (a-b)/(a+b)
elseif ell=='wgs84',       	// WGS84-Ellipsoid
   a  = 6378137;
   c  = 6399593.626;
   es = 0.00673949674226;
   n  = 0.00167922038638;
elseif ell=='grs80',       		// GRS80-Ellipsoid
   a  = 6378137;
   c  = 6399593.626;
   es = 0.00673949677548;
   n  = 0.00167922039463;
else
   error('Nicht-definiertes Ellipsoid')
end

// GK Konvention in  der Bundesrepublik Deutschland
   masstab = 1;
   y0 = 500000;
   bb = B *%pi/180;
   ll = (L-L0) *%pi/180;

// Berechnung Fupunktsbreite
   eta2 = es .* (cos(bb)).^2;
   v = sqrt(1+eta2);
   bf = atan(tan(bb) ./ cos(v.*ll) .* (1 + eta2/6 .* (1-3*sin(bb).^2) .* ll.^4));

// Berechnung der Meridianbogenlnge aus Fupunktbreite
   b0 = (1 + n^2 / 4 + n^4 / 64) * bf;
   b2 = -1.5*n * (1-n^2/8) * sin(2.*bf);
   b4 = 15/16 * n^2 * (1 - n^2/4)*sin(4*bf);
   b6 = -35 / 48 * n^3 * sin(6*bf);
   b8 = 315 / 512 * n^4 * sin(8*bf);

   g = a / (1+n) * (b0 + b2 + b4 + b6 + b8);

// Berechnung Hochwert
   H = g * masstab;

// Berechnung Rechtswert
   eta2f = es .* cos(bf).^2;
   vf = sqrt(1+eta2f);
   ys0 = tan(ll) .* cos(bf) ./ vf;
   ys0 = ys0 .* (1 + eta2f .* ll.^2 .* cos(bf).^2 .* (eta2f/6 + ll.^2/10) );
   ys = asinh(ys0);
   R = (ys .* c * masstab) + (L0/3)*1e6 + y0;

endfunction;
